@@ -54,7 +54,7 @@
 #' @examples 
 #' \dontrun{
 #' data(small.16S)
-#' tax.tab <- taxMachine( small.16S$Sequence )
+#' tax.tab <- taxMachine(small.16S$Sequence)
 #' }
 #' 
 #' @importFrom utils data
@@ -62,31 +62,31 @@
 #' @importFrom stats approx median
 #' @export taxMachine
 #' 
-taxMachine <- function( sequence, model.in.memory=TRUE, model.on.disk = FALSE,
-                        verbose=TRUE, chunk.size=10000 ){
-  if( verbose ) cat( "Welcome to the taxMachine!\n")
-  N.seq <- length( sequence )
-  if( !(is.numeric(chunk.size) & chunk.size>0) ) stop( "chunk.size must be a positive integer" )
-  chunks <- unique( c( seq( 0, N.seq, chunk.size ), N.seq ) )
-  nc <- length( chunks )
-  sl <- nchar( sequence )
-  if( verbose ) cat( "   classifying", N.seq, "sequences with median length", median( sl ), "...\n" )
-  ml <- c( 150, 300, 500, 1400 )
-  dl <- abs( median( sl ) - ml )
-  ml <- ml[which( dl == min( dl ) )[1]]
+taxMachine <- function(sequence, model.in.memory = TRUE, model.on.disk = FALSE,
+                        verbose = TRUE, chunk.size = 10000){
+  if(verbose) cat("Welcome to the taxMachine!\n")
+  N.seq <- length(sequence)
+  if(!(is.numeric(chunk.size) & chunk.size>0)) stop("chunk.size must be a positive integer")
+  chunks <- unique(c(seq(0, N.seq, chunk.size), N.seq))
+  nc <- length(chunks)
+  sl <- nchar(sequence)
+  if(verbose) cat("   classifying", N.seq, "sequences with median length", median(sl), "...\n")
+  ml <- c(150, 300, 500, 1400)
+  dl <- abs(median(sl) - ml)
+  ml <- ml[which(dl == min(dl))[1]]
   n.pseudo <- 100
   
   # Check if model is saved or should be saved
   do.load <- do.save <- FALSE
-  if( is.character( model.on.disk ) | ( is.logical( model.on.disk ) && model.on.disk ) ){
-    if( is.logical( model.on.disk ) ){
-        model.on.disk <- file.path( path.package( "microclass" ), "extdata/model100.rda" ) 
+  if(is.character(model.on.disk) | (is.logical(model.on.disk) && model.on.disk)){
+    if(is.logical(model.on.disk)){
+        model.on.disk <- file.path(path.package("microclass"), "extdata/model100.rda") 
     }
-    if( file.exists( model.on.disk ) ){
-      load( model.on.disk )
-      if( !exists( "fitted.model" ) ) stop( 'fitted.model was not found in saved file.' )
+    if(file.exists(model.on.disk)){
+      load(model.on.disk)
+      if(!exists("fitted.model")) stop('fitted.model was not found in saved file.')
       do.load <- TRUE
-      if( verbose ) cat( "   model loaded...\n" )
+      if(verbose) cat("   model loaded...\n")
     } else {
       do.save <- TRUE
     }
@@ -94,56 +94,56 @@ taxMachine <- function( sequence, model.in.memory=TRUE, model.on.disk = FALSE,
   
   # Check if counts and/or correct model is cached
   do.cache <- was.cached <- FALSE
-  if( !do.load && model.in.memory ){
-    fitted.model <- getmicroEnv( "fitted.model" )
-    if( is.null( fitted.model ) ){
+  if(!do.load && model.in.memory){
+    fitted.model <- getmicroEnv("fitted.model")
+    if(is.null(fitted.model)){
       do.cache <- TRUE
     } else {
       was.cached <- TRUE
-        if( verbose ) cat( "   reusing model...\n" )
+        if(verbose) cat("   reusing model...\n")
     }
   }
   
   # Create multinomial model if not available
-  if( !do.load && !was.cached ){
-    if( verbose ) cat( "   creating model...\n" )
+  if(!do.load && !was.cached){
+    if(verbose) cat("   creating model...\n")
     contax.trim <- NULL
-    load( file.path( path.package( "microcontax" ), "data/contax.trim.rda" ) )
-    fitted.model <- multinomTrain( contax.trim$Sequence, getGenus(contax.trim$Header), n.pseudo=n.pseudo )
+    load(file.path(path.package("microcontax"), "data/contax.trim.rda"))
+    fitted.model <- multinomTrain(contax.trim$Sequence, getGenus(contax.trim$Header), n.pseudo = n.pseudo)
   }
   
   coef.bias <- coef.sd <- std.frame <- rprob.mat <- NULL
-  load( file.path( path.package( "microclass" ), "extdata/norm.models.rda" ) )
-  load( file.path( path.package( "microclass" ), "extdata/std.frame.rda" ) )
-  load( file.path( path.package( "microclass" ), paste( "extdata/rprob.mat.", ml, ".rda", sep="" ) ) )
+  load(file.path(path.package("microclass"), "extdata/norm.models.rda"))
+  load(file.path(path.package("microclass"), "extdata/std.frame.rda" ) )
+  load(file.path(path.package("microclass"), paste0("extdata/rprob.mat.", ml, ".rda")))
   
   
   # Save multinomial model for later use
-  if( do.save ){
-    if( verbose ) cat( "   saving model...\n" )
-    save( fitted.model, file = model.on.disk, compress = "xz" )
+  if(do.save){
+    if(verbose) cat("   saving model...\n")
+    save(fitted.model, file = model.on.disk, compress = "xz")
   }
-  if( do.cache ){
-    if( verbose ) cat( "   caching model...\n" )
-    putmicroEnv( "fitted.model", fitted.model )
+  if(do.cache){
+    if(verbose) cat("   caching model...\n")
+    putmicroEnv("fitted.model", fitted.model)
   }
   
-  restab <- data.frame( Genus=rep( "unclassified", N.seq ),
-                        D.score=rep( 0, N.seq ),
-                        R.score=rep( 0, N.seq ),
-                        P.recognized=rep( 1, N.seq ),
-                        stringsAsFactors=F )
-  for( i in 1:(nc-1) ){
+  restab <- data.frame(Genus = rep("unclassified", N.seq),
+                        D.score = rep(0, N.seq),
+                        R.score = rep(0, N.seq),
+                        P.recognized = rep(1, N.seq),
+                        stringsAsFactors = F)
+  for(i in 1:(nc-1)){
     idx <- (chunks[i]+1):chunks[i+1]
-    if( verbose ) cat( "   classifying sequence", min( idx ), "to", max( idx ), "\n" )
-    dfr <- multinomClassify( sequence[idx], fitted.model, post.prob=T )
+    if(verbose) cat("   classifying sequence", min(idx), "to", max(idx), "\n")
+    dfr <- multinomClassify(sequence[idx], fitted.model, post.prob = T)
     l <- sl[idx]
-    P1 <- ( dfr$Post.prob.1 - (coef.bias[1]+coef.bias[2]*l) )/(coef.sd[1]+coef.sd[2]*l)
-    P2 <- ( dfr$Post.prob.2 - (coef.bias[1]+coef.bias[2]*l) )/(coef.sd[1]+coef.sd[2]*l)
+    P1 <- (dfr$Post.prob.1 - (coef.bias[1]+coef.bias[2]*l))/(coef.sd[1]+coef.sd[2]*l)
+    P2 <- (dfr$Post.prob.2 - (coef.bias[1]+coef.bias[2]*l))/(coef.sd[1]+coef.sd[2]*l)
     Ds <- P1 - P2
-    idd <- as.integer( factor( dfr$Taxon.1, levels=std.frame[,1] ) )
+    idd <- as.integer(factor(dfr$Taxon.1, levels = std.frame[,1]))
     Rs <- (P1 - std.frame[idd,2])/std.frame[idd,3]
-    lst <- approx( rprob.mat[,1], rprob.mat[,2], xout=Rs, yleft=0, yright=1 )
+    lst <- approx(rprob.mat[,1], rprob.mat[,2], xout = Rs, yleft = 0, yright = 1)
     
     restab$Genus[idx] <- dfr$Taxon.1
     restab$D.score[idx] <- Ds
@@ -151,8 +151,8 @@ taxMachine <- function( sequence, model.in.memory=TRUE, model.on.disk = FALSE,
     restab$P.recognized[idx] <- lst$y
   }
   
-  if( verbose ) cat( "done!\n" )
-  return( restab )
+  if(verbose) cat("done!\n")
+  return(restab)
 }
 
 ## Backup: No space saving
